pub struct ContactInformation {
pub pid: String,
pub pref: u8,
pub value: String,
pub platform: ContactPlatform,
pub typ: Option<Type>,
}Expand description
Represents any way which a contact can be contacted.
This may be a phone number, an email etc. You can add
any number of them to a Contact.
Fields
pid: StringThe pid, used for representing this amongst
other ContactInformations.
pref: u8The Preference Value. In this implementation 0 represents that it is neutral, not either way.
value: StringThe Value (for example johndoe@example.com)
platform: ContactPlatformThe platform which this is on
typ: Option<Type>The type
Implementations
Sourceimpl ContactInformation
impl ContactInformation
Sourcepub fn new(string: String, platform: ContactPlatform) -> Self
pub fn new(string: String, platform: ContactPlatform) -> Self
Creates a new ContactInformation
This also auto generates a pid between 0 and 100